Learn R Programming

descsuppR (version 1.2)

w.CochraneArmitageTrend.test: Cochran-Armitage Test for Trend

Description

Wrapper for CochranArmitageTest which is a test for trend in binomial proportions across the levels of a single variable

Usage

w.CochraneArmitageTrend.test(values, grouping, ...)

Value

the value of CochranArmitageTest

Arguments

values

vector. The values to compare. Will be passed to circular to be converted to circular format

grouping

of the same length as values. treated as factor giving the group membership

...

additional parameters. are passed on to the CochranArmitageTest

Author

Dr. Andreas Leha