npar.t.test with unified interface
w.npar.t.test.permu(values, grouping, ...)the value npar.t.test
vector. The values to compare (age, toxicity score, gene expression, ...)
vector of the same length as values. treated as factor giving the group membership
additional parameters. are passed on to the npar.t.test
Fabian Kück
just a call to npar.t.test that unifies the api to other tests computes the the studentized permutation test version of the Brunner-Munzel test