change the description into the long format
calc_descr_long(
x,
xname,
extraLevels = NULL,
includeNAs = FALSE,
includeNonNAs = FALSE,
orderedAsUnordered = FALSE,
factorlevellimit = 14,
show.minmax = TRUE,
show.IQR = FALSE,
sd_digits = "by_mean",
descr_digits = 2,
significant_digits = TRUE
)data.frame of character describing x
vector of which to calc the descriptive values
the name of the variable encoded in x
named list of lists. Names have to be variable names. Elements have to have to be named list of this form: `some label` = list(idxvec = idxvec, display = logical). Here idxvec needs to be a logical vector of length nrow(df) that specifies the affected rows. If display is TRUE the number of affected rows will be shown under some label.
logical. include the number of NAs in the output?
logical. treat ordered factors as unordered factors?
integer. for factors with more than
factorlevellimit levels, not all levels are printed
logical. if TRUE show minimum and maximum for numeric variables. Defaults to TRUE.
logical. if TRUE show 25% and 75% quantiles for numeric variables. Defaults to FALSE.
character. one of c("by_mean", "fixed"). If 'by_mean', the number of decimal places of the standard deviation is limited by the number of decimal places of the mean.
integer. Number of digits for formatting of descriptive values. Defaults to 2.
boolean. if TRUE, the number of significant digits of is given by descr_digits. Otherwise the number of decimal places is fixed.
Andreas Leha
only for internal use.